#!/usr/bin/perl
use strict;
use warnings;
use FileHandle;
use File::Basename;

###################################################
##               Script1-REDDB.pl                ##
##                 Version 1.01                  ##
##                                               ##
##      Automatic submission in R.E.DD.B.        ##
##    http://q4md-forcefieldtools.org/REDDB/     ##
##                                               ##
##                UPJV - SBMRI                   ##
##                                               ##
##   See the license of the R.E.D.-III.x tools   ##
###################################################
##
## Version 1.0  - November 24th, 2011
## Version 1.01 - December 8th, 2011
## - Added new pieces of information in the .cfg file to help users
## - Automatically detect the directory names generated by the different versions
##   of the R.E.D. tools and R.E.D. Server
##
## *****************************************************************
##    Program developed at the UFR de Pharmacie in Amiens by:
##     Q. Defarcy,(1) P. Cieplak (2) & F.-Y. Dupradeau (1)
##
## (1) UMR-CNRS 6219, UFR de Pharmacie, Amiens, France
## (2) Sanford|Burnham Medical Research Institute, La Jolla, CA, USA
## *****************************************************************
##
##              Execution:
## perl Script1-REDDB.pl DataDirectory
##   "DataDirectory": Directory containing data generated by R.E.D.-III.x 
##                                                     or by R.E.D. Server/R.E.D. IV
##  -> a "DataDirectory-config.cfg" file is generated
##     This file can be manually modified...
##
## Do you have questions about this program?
## Please register @ http://lists.q4md-forcefieldtools.org/wws/info/q4md-fft
##  & send your queries to the q4md-fft mailing list

my $nbp2n;
my $nbinp;
my $nbmol2;
my $nbscript;
my $testdir;
my $dir;
my $dir1;
my @pathmol2;
my @pdbpath;
my @tmpinp;
my @TITLE;
my @TER;
my @RP;
my @NO;
my $NOP;
my @NOP;
my $NM;
my $nbp2ntot;
my $WF;
my $QMLOG1;
my $QMLOG2;
my $QMSOFT1;
my $QMSOFT2;
my $okqm1;
my $okqm2;
my $TL1;
my $TL2;
my $BS1;
my $BS2;
my $MI1;
my $MI2;
my $SA;

sub OpenP2N {
	$WF = "W";
	open(P2NFILE,"< $ARGV[0]/Mol_red$nbp2n.p2n");
	foreach(<P2NFILE>){
		if(/^REMARK TITLE/) {
			($TITLE[$nbp2n]) = (split(' '))[2];
			if (defined ($TITLE[$nbp2n])) { $TITLE[$nbp2n] =~ s/^\s*(.*?)\s*$/$1/; }
			else { $TITLE[$nbp2n]="UNDEFINED"; }
			# print "$nbp2n TITLE = $TITLE[$nbp2n]\n";
		}
		if((/^REMARK INTRA-MCC/) || (/^REMARK INTER-MCC/)) { $WF = "F"; }
	}
	close(P2NFILE);
	# print "Fragment/molecule = $WF\n";
}

#---------------------------- Check Pathfile ----------------------------------
sub verifdir{
	my $all = 0;
	if (($#ARGV == 0)){
	#$dir = "/bin/ls $ARGV[0] -d";
		if (-e "$ARGV[0]"){
			$nbp2n = 0;
			$NM=1;
			while(-e "$ARGV[0]/Mol_red$NM.p2n"){ $nbp2n++; $NM++; }
			$nbp2ntot =  $nbp2n;
			# print "nbp2ntot = $nbp2ntot\n";
			if ($nbp2ntot == 0){
				$all = 1;
				print "\n==================================================================\n";
				print "No P2N file(s) is found. Exit\t\t\t[ERROR]\n";
				print "==================================================================\n\n";
			}else{
				if ((($nbp2ntot == 1) && (-e "$ARGV[0]/$_[0]")) || (($nbp2ntot > 1) && (-e "$ARGV[0]/$_[0]/Mol_MM"))){ }
				else{
					$all = 2;
					print "\n==================================================================\n";
					print "The subdirectory \"$_[0]\" in \"$ARGV[0]\" is not found.\t\t\t[ERROR]\n";
					print "==================================================================\n\n";
				}
			}
		}else{
			$all = 1;
			print "\n==================================================================\n";
			print "The directory $ARGV[0] is not found!\t\t\t[ERROR]\n";
			print "==================================================================\n\n";
		}
	}else{
		$all = 1;
		print "\n===================================================================\n";
		print "Provide a R.E.D. Server Job name/a directory name...\t[ERROR]\n";
		print "===================================================================\n\n";
	}
	return $all;
}

if    (defined($ARGV[0]) && -e "$ARGV[0]/CHRCalc")     { $dir1 ='CHRCalc'; }     # Used in R.E.D. I & R.E.D. II
elsif (defined($ARGV[0]) && -e "$ARGV[0]/0Values")     { $dir1 ='0Values'; }     # Used in R.E.D. III & R.E.D. III.1
# elsif (defined($ARGV[0]) && -e "$ARGV[0]/Data")        { $dir1 ='Data'; }      # Used in R.E.D. III.2   ->   Desactivated: too general
elsif (defined($ARGV[0]) && -e "$ARGV[0]/Data-RED")    { $dir1 ='Data-RED'; }    # Used in R.E.D. III.3 & R.E.D. III.4
elsif (defined($ARGV[0]) && -e "$ARGV[0]/Data-R.E.D.") { $dir1 ='Data-R.E.D.'; } # 
else  { $dir1 ='$ARGV[0]/Data-R.E.D.Server'; }
$dir = (split (/\//, $dir1))[1];
$testdir = verifdir($dir);
while ($testdir == 2){
	print "Enter the name of subdirectory: $ARGV[0]/";
	$dir = <STDIN>;
	my $poubelle = chomp($dir);
	$testdir = verifdir($dir);
}
#==============================================================================

if ($testdir == 0){
open(CONFIG,">$ARGV[0]-config.cfg");
print CONFIG "###############################################################################\n";
print CONFIG "##                                                                           ##\n";
print CONFIG "## Welcome to the 'config.cfg' file for configuring your R.E.DD.B. project.  ##\n";
print CONFIG "##         Please, enter the data corresponding to your project.             ##\n";
print CONFIG "##                                                                           ##\n";
print CONFIG "###############################################################################\n";
print CONFIG "#\n";
print CONFIG "###############################################################################\n";
print CONFIG "##                                                                           ##\n";
print CONFIG "##       Delete and replace '____' with the corresponding information.       ##\n";
print CONFIG "##         Use the '<!>' characters when needed to separate two fields       ##\n";
print CONFIG "##                                                                           ##\n";
print CONFIG "###############################################################################\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==================== R.E.DD.B. Root login and password =======================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# These pieces of information remain ALWAYS UNKNOWN to the user\n";
print CONFIG "<REDDB_Root_Login>\n";
print CONFIG "_____\n";
print CONFIG "<!_REDDB_Root_Login>\n";
print CONFIG "#\n";
print CONFIG "<REDDB_Root_Password>\n";
print CONFIG "_____\n";
print CONFIG "<!_REDDB_Root_Password>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#======================= R.E.DD.B. login and password =========================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# No default value: to be provided by the user after having excuted the Script1-REDDB.pl\n";
print CONFIG "# The user needs first to register at http://q4md-forcefieldtools.org/REDDB/\n";
print CONFIG "<Your_REDDB_Login>\n";
print CONFIG "_____\n";
print CONFIG "<!_Your_REDDB_Login>\n";
print CONFIG "#\n";
print CONFIG "<Your_REDDB_Password>\n";
print CONFIG "_____\n";
print CONFIG "<!_Your_REDDB_Password>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================ Project Name ================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# No default value: to be provided by the user after having excuted the Script1-REDDB.pl\n";
print CONFIG "<Project_Name>\n";
print CONFIG "__________\n";
print CONFIG "<!_Project_Name>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================= Protection =================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# To be modified if you do not agree with these default options...\n";
print CONFIG "# Do you wish to protect the current project?\n";
print CONFIG "# Write 'Yes' or 'No'; default value = 'Yes'.\n";
print CONFIG "#\n";
print CONFIG "<Protect>\n";
print CONFIG "Yes\n";
print CONFIG "<!_Protect>\n";
print CONFIG "#\n";
print CONFIG "# - If Yes, period of protection:\n";
print CONFIG "# Write '3', '6' or '12' for 3 months, 6 months or 12 months.\n";
print CONFIG "#\n";
print CONFIG "<ProtectPeriod>\n";
print CONFIG "3\n";
print CONFIG "<!_ProtectPeriod>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================ GENERAL INFORMATION ABOUT THE PROJECT =======================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============================== Molecule keyword ==============================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# No default value: to be provided by the user after having excuted the Script1-REDDB.pl\n";
print CONFIG "<Molecule_Keyword>\n";
print CONFIG "__________ <!> __________ <!> __________ <!> __________ <!> __________\n";
print CONFIG "<!_Molecule_Keyword>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================= Abstract ===================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# No default value: to be provided by the user after having excuted the Script1-REDDB.pl\n";
print CONFIG "# Please, provide an abstract in the text/html format (W3C compliant)\n";
print CONFIG "<Abstract>\n";
print CONFIG "__________\n";
print CONFIG "<!_Abstract>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================== Publication ===============================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# To be modified if you do not agree with these default options...\n";
print CONFIG "# Is the current project already published?\n"; 
print CONFIG "# Write 'Yes' or 'No'; default value = 'No'.\n";
print CONFIG "#\n";
print CONFIG "<Published>\n";
print CONFIG "No\n";
print CONFIG "<!_Published>\n";
print CONFIG "#\n";
print CONFIG "# - If 'Yes' -\n";
print CONFIG "#   Author(s)  <!> Journal  <!>   Year   <!>  Volume  <!>  Page(s)  <!> PMID\n";
print CONFIG "#\n";
print CONFIG "<Pubinfo>\n";
print CONFIG "______________ <!> ________ <!> ________ <!> ________ <!> ____-____ <!> _________\n";
print CONFIG "<!_Pubinfo>\n";
print CONFIG "#\n";

for($nbp2n=1; $nbp2n<=$nbp2ntot; $nbp2n++) { 
	OpenP2N();
	if ($WF eq "F") { last; }
}

print CONFIG "#==============================================================================\n";
print CONFIG "#==================== Whole molecule or Molecule fragment =====================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Is your project a 'WHOLE MOLECULE' or a 'MOLECULE FRAGMENT'?\n";
print CONFIG "# Write 'F' for FRAGMENT or 'W' for WHOLE; default value = 'W'.\n";
print CONFIG "#\n";
print CONFIG "<WholeFragment>\n";
print CONFIG "$WF\n";
print CONFIG "<!_WholeFragment>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#=============================== R.E.D. Interface =============================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# To be modified if you do not agree with these default options...\n";
print CONFIG "# Was the R.E.D. interface used to generate the data?\n";
print CONFIG "# Write 'Yes' or 'No'; default value = 'Yes'.\n";
print CONFIG "#\n";
print CONFIG "<REDInterface>\n";
print CONFIG "Yes\n";
print CONFIG "<!_REDInterface>\n";
print CONFIG "# \n";

print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==================== CHARGE DERIVATION PROCEDURE =============================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================= Information about the PDB files ============================\n";
print CONFIG "#==============================================================================\n";

for($nbp2n=1; $nbp2n<=$nbp2ntot; $nbp2n++) {
	if ($nbp2ntot == 1){
		if (-e "$ARGV[0]/$dir/File4REDDB_m$nbp2n.pdb") { 
			open(PDBFILE,"< $ARGV[0]/$dir/File4REDDB_m$nbp2n.pdb");
			$pdbpath[$nbp2n]="$ARGV[0]/$dir/File4REDDB_m$nbp2n.pdb";

			$TER[$nbp2n]="1";
			$RP[$nbp2n]="QMRA";
			foreach(<PDBFILE>){
				if(/^TER/) { $TER[$nbp2n]++; }
				if(/^REMARK REORIENT/) { 
					$RP[$nbp2n]="RBRA"; 
					s/[^\d|]//gi;
					@NO = split("[|]");
					$NOP=$#NO+1;
					$NOP[$nbp2n]=$NOP;
					# print "\n\t RBRA: $_ ; NB Orient = $NOP[$nbpdb] \n";
				}
				elsif(/^REMARK QMRA/) { $NOP[$nbp2n]=1; }
			}
			close(PDBFILE);
		}
		else {
			$TER[$nbp2n]=$RP[$nbp2n]=$NOP[$nbp2n]=$pdbpath[$nbp2n]="?";
			print "\n$ARGV[0]/$dir/File4REDDB_m$nbp2n.pdb is not found...";
		} 
	}
	else {
		if (-e "$ARGV[0]/$dir/Mol_m$nbp2n/File4REDDB_m$nbp2n.pdb") { 
			open(PDBFILE,"< $ARGV[0]/$dir/Mol_m$nbp2n/File4REDDB_m$nbp2n.pdb");
			$pdbpath[$nbp2n]="$ARGV[0]/$dir/Mol_m$nbp2n/File4REDDB_m$nbp2n.pdb";

			$TER[$nbp2n]="1";
			$RP[$nbp2n]="QMRA";
			foreach(<PDBFILE>){
				if(/^TER/) { $TER[$nbp2n]++; }
				if(/^REMARK REORIENT/) { 
					$RP[$nbp2n]="RBRA"; 
					s/[^\d|]//gi;
					@NO = split("[|]");
					$NOP=$#NO+1;
					$NOP[$nbp2n]=$NOP;
					# print "\n\t RBRA: $_ ; NB Orient = $NOP[$nbpdb] \n";
				}
				elsif(/^REMARK QMRA/) { $NOP[$nbp2n]=1; }
			}
			close(PDBFILE);
		}
		else { 
			$TER[$nbp2n]=$RP[$nbp2n]=$NOP[$nbp2n]=$pdbpath[$nbp2n]="?";
			print "\n$ARGV[0]/$dir/File4REDDB_m$nbp2n.pdb is not found..."; } 
	}
	OpenP2N();
}

print CONFIG "# Automatically determined from the list of P2N files...\n";
print CONFIG "# Index of the file\n";
print CONFIG "# (MN) Molecule name (following IUPAC rules)\n";
print CONFIG "# (NC) Number of molecular conformation(s) for the considered molecule\n";
print CONFIG "# (RP) Reorientation procedure used before MEP computation: QMRA or RBRA\n";
print CONFIG "# (NO) Number of molecular orientation(s) for each conformation\n";
print CONFIG "# (PF) Path to the PDB file and file name\n";
print CONFIG "#\n";
print CONFIG "# Index   <!>                   (MN)                   <!> (NC) <!> (RP) <!> (NO) <!>  (PF)\n";
print CONFIG "<PDBFile_Name>\n";

format PDBFILE=
File @### <!> @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< <!> @>>> <!> @>>> <!> @>>> <!> @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
     $nbp2n,              $TITLE[$nbp2n],            $TER[$nbp2n], $RP[$nbp2n], $NOP[$nbp2n], $pdbpath[$nbp2n]
.

	format_name CONFIG "PDBFILE";
	for($nbp2n=1; $nbp2n<=$nbp2ntot; $nbp2n++) { write CONFIG; }

print CONFIG "<!_PDBFile_Name>\n";

print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============== Information about the Tripos MOL2 files =======================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined... \n";
print CONFIG "# However, you could add or remove some pieces of information depending on your choices... \n";
print CONFIG "# Index of the file\n";
print CONFIG "# (NMF) Name for the corresponding molecule/fragment\n";
print CONFIG "# (PF)  Path to the Tripos mol2 file and file name\n";
print CONFIG "#\n";
print CONFIG "# Only the conformation 'o1' is considered for submission in R.E.DD.B.\n";
print CONFIG "#\n";
print CONFIG "# Index   <!>                (NMF)                 <!>   (PF)\n";
print CONFIG "<TriposFile_Name>\n";

format MOL2FILE=
File @### <!> @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< <!> @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 $nbmol2,     $TITLE[$nbmol2],                          $pathmol2[$nbmol2]
.

format_name CONFIG "MOL2FILE";
	$nbmol2=1;
	for($nbp2n=1; $nbp2n<=$nbp2ntot; $nbp2n++) {
		if (-e "$ARGV[0]/$dir/Mol_m$nbp2n-o1.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_m$nbp2n-o1.mol2";    $TITLE[$nbmol2]=$TITLE[$nbp2n];               write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_m$nbp2n-o1-sm.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_m$nbp2n-o1-sm.mol2"; $TITLE[$nbmol2]="Fragment-SM_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }

		if (-e "$ARGV[0]/$dir/Mol_MM/Mol_m$nbp2n-o1-mm1.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/Mol_m$nbp2n-o1-mm1.mol2"; $TITLE[$nbmol2]=$TITLE[$nbp2n]; write CONFIG; $nbmol2++;}
		if (-e "$ARGV[0]/$dir/Mol_MM/Mol_m$nbp2n-o1-mm2.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/Mol_m$nbp2n-o1-mm2.mol2"; $TITLE[$nbmol2]=$TITLE[$nbp2n]; write CONFIG; $nbmol2++;}
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.mol2")	        { OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.mol2";        $TITLE[$nbmol2]=$TITLE[$nbp2n]; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG1.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG1.mol2";    $TITLE[$nbmol2]="Fragment-FG1_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG2.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG2.mol2";    $TITLE[$nbmol2]="Fragment-FG2_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG3.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG3.mol2";    $TITLE[$nbmol2]="Fragment-FG3_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG4.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG4.mol2";    $TITLE[$nbmol2]="Fragment-FG4_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG5.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG5.mol2";    $TITLE[$nbmol2]="Fragment-FG5_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG6.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG6.mol2";    $TITLE[$nbmol2]="Fragment-FG6_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG7.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG7.mol2";    $TITLE[$nbmol2]="Fragment-FG7_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG8.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG8.mol2";    $TITLE[$nbmol2]="Fragment-FG8_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG9.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG9.mol2";    $TITLE[$nbmol2]="Fragment-FG9_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG10.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1.FG10.mol2";    $TITLE[$nbmol2]="Fragment-FG10_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-FG.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-FG.mol2";     $TITLE[$nbmol2]="Fragment-FG_$TITLE[$nbp2n]";  write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-CT-A.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-CT-A.mol2";   $TITLE[$nbmol2]="Fragment-CTA_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-CT-B.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-CT-B.mol2";   $TITLE[$nbmol2]="Fragment-CTB_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OX-A.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OX-A.mol2";   $TITLE[$nbmol2]="Fragment-OXA_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OX-B.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OX-B.mol2";   $TITLE[$nbmol2]="Fragment-OXB_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OY-A.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OY-A.mol2";   $TITLE[$nbmol2]="Fragment-OYA_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
		if (-e "$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OY-B.mol2")	{ OpenP2N(); $pathmol2[$nbmol2]="$ARGV[0]/$dir/Mol_MM/mm$nbp2n-o1-OY-B.mol2";   $TITLE[$nbmol2]="Fragment-OYB_$TITLE[$nbp2n]"; write CONFIG; $nbmol2++; }
	}
	$nbmol2--;
if ($nbmol2==0) {
	print "\n\nError, no mol2 file found...\n";
	print CONFIG "__________\n";
}
print CONFIG "<!_TriposFile_Name>\n";

$QMLOG1 = $QMLOG2= "";
# Select data corresponding to the last P2N file
# print "\n\nLast P2N file: $nbp2ntot\n";
if (-e "$ARGV[0]/Mol_red$nbp2ntot.log")					{ $QMLOG1 = "$ARGV[0]/Mol_red$nbp2ntot.log"; }
elsif (-e "$ARGV[0]/$dir/JOB1-gam_m$nbp2ntot-1.log")			{ $QMLOG1 = "$ARGV[0]/$dir/JOB1-gam_m$nbp2ntot-1.log"; }
elsif (-e "$ARGV[0]/$dir/JOB1-gau_m$nbp2ntot-1.log")			{ $QMLOG1 = "$ARGV[0]/$dir/JOB1-gau_m$nbp2ntot-1.log"; }
elsif (-e "$ARGV[0]/$dir/JOB1-gau_m$nbp2ntot-1.out")			{ $QMLOG1 = "$ARGV[0]/$dir/JOB1-gau_m$nbp2ntot-1.out"; }
elsif (-e "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB1-gam_m$nbp2ntot-1.log")	{ $QMLOG1 = "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB1-gam_m$nbp2ntot-1.log"; }
elsif (-e "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB1-gau_m$nbp2ntot-1.log")	{ $QMLOG1 = "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB1-gau_m$nbp2ntot-1.log"; }
elsif (-e "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB1-gau_m$nbp2ntot-1.out")	{ $QMLOG1 = "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB1-gau_m$nbp2ntot-1.out"; }
else { print "\n\nError, no geometry optimization found...\n"; }

if (-e "$ARGV[0]/$dir/JOB2-gam_m$nbp2ntot-1-1.log")			{ $QMLOG2 = "$ARGV[0]/$dir/JOB2-gam_m$nbp2ntot-1-1.log"; }
elsif (-e "$ARGV[0]/$dir/JOB2-gam_m$nbp2ntot-1-1.log")			{ $QMLOG2 = "$ARGV[0]/$dir/JOB2-gam_m$nbp2ntot-1-1.log"; }
elsif (-e "$ARGV[0]/$dir/JOB2-gau_m$nbp2ntot-1-1.log")			{ $QMLOG2 = "$ARGV[0]/$dir/JOB2-gau_m$nbp2ntot-1-1.log"; }
elsif (-e "$ARGV[0]/$dir/JOB2-gau_m$nbp2ntot-1-1.out")			{ $QMLOG2 = "$ARGV[0]/$dir/JOB2-gau_m$nbp2ntot-1-1.out"; }
elsif (-e "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB2-gam_m$nbp2ntot-1-1.log")	{ $QMLOG2 = "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB2-gam_m$nbp2ntot-1-1.log"; }
elsif (-e "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB2-gau_m$nbp2ntot-1-1.log")	{ $QMLOG2 = "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB2-gau_m$nbp2ntot-1-1.log"; }
elsif (-e "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB2-gau_m$nbp2ntot-1-1.out")	{ $QMLOG2 = "$ARGV[0]/$dir/Mol_m$nbp2ntot/JOB2-gau_m$nbp2ntot-1-1.out"; }
else { print "\n\nError, no MEP computation found...\n"; }

# print "\n\nQMLOG1 = $QMLOG1; QMLOG2 = $QMLOG2\n";

$okqm1 = $okqm2 = 1;
$QMSOFT1 = $QMSOFT2 = $TL1 = $TL2 = $BS1 = $BS2 = $MI1 = $MI2 = $SA = "__________";
open(QMLOGFILE1,"< $QMLOG1");
foreach(<QMLOGFILE1>){
	if((/Normal termination/ig) || (/TERMINATED NORMALLY/ig))		{ $okqm1=0; }
}
close(QMLOGFILE1);

my $IG1= my $GB1= my $PA= my $P1A= my $P2A= my $DA= my $D1A= my $D2A= my $FLG1A= my $FLG2A= my $FLG3A= my $FLG4A=0;
my $G = "G";

if ($okqm1==0) {
	open(QMLOGFILE1,"< $QMLOG1");
	foreach(<QMLOGFILE1>){
		if(/M.W.SCHMIDT, K.K.BALDRIDGE, J.A.BOATZ/g) 				{ $QMSOFT1="GAMESS"; }
		elsif(/gran\@classic.chem.msu.su/g) 					{ $QMSOFT1="FIREFLY"; }
		elsif(/Gaussian 98:/g) 							{ $QMSOFT1="GAUSSIAN 1998"; }
		elsif(/Gaussian 03:/g) 							{ $QMSOFT1="GAUSSIAN 2003"; }
		elsif(/Gaussian 09:/g) 							{ $QMSOFT1="GAUSSIAN 2009"; }

		if(/E\(RHF\)/ig || /SCFTYP=RHF/g) 					{ $TL1="RHF"; }			# Gaussian & GAMESS/Firefly
		elsif(/E\(UHF\)/ig || /SCFTYP=UHF/g) 					{ $TL1="UHF"; }			# Gaussian & GAMESS/Firefly

		if(/6-31G\*/ig || /6-31G\(d\)/ig) 					{ $BS1="6-31G*"; }		# Gaussian
		elsif(/6-311G\*/ig || /6-311G\(d\)/ig) 					{ $BS1="6-311G*"; }
		elsif(/6-31\+G\*/ig || /6-31\+G\(d\)/ig) 				{ $BS1="6-31+G*"; }
		elsif(/6-31\+\+G\*/ig || /6-31\+\+G\(d\)/ig) 				{ $BS1="6-31++G*"; }
		elsif(/6-31\+\+G\*\*/ig || /6-31\+\+G\(d\,p\)/ig) 			{ $BS1="6-31++G**"; }

		else {													# GAMESS/FIREFLY
			#     GBASIS=N31          IGAUSS=       6      POLAR=POPN31  
			#     NDFUNC=       1     NFFUNC=       0     DIFFSP=       F
			#     NPFUNC=       0      DIFFS=       F     BASNAM=        
			if (/GBASIS=N311/g)						{ $GB1="311"; $FLG1A=1; }
			if (/GBASIS=N31/g)						{ $GB1="31";  $FLG1A=1; }
			if (/GBASIS=N21/g)						{ $GB1="21";  $FLG1A=1; }
			if (/GBASIS=STO/g)						{ $GB1="STO"; $FLG1A=1; }

			if (/IGAUSS=       6/g)						{ $IG1="6";   $FLG2A=1; }
			if (/IGAUSS=       3/g)						{ $IG1="3";   $FLG2A=1; }

			if (/NDFUNC=       1/g)						{ $P1A='1'; }
			if (/NPFUNC=       1/g)						{ $P2A='1'; }
			if ($P1A==1)							{ $PA='*';    $FLG3A=1; }
			if (($P1A==1) && ($P2A==1))					{ $PA='**';   $FLG3A=1; }

			if (/DIFFS=       T/g)						{ $D1A='1'; }
			if (/DIFFSP=       T/g)						{ $D2A='1'; }
			if ($D1A==1)							{ $DA='+';    $FLG4A=1; }
			if (($D1A==1) && ($D2A==1))					{ $DA='++';   $FLG4A=1; }

			if (($FLG1A==1) && ($FLG2A==1) && ($FLG3A==1))			{ $BS1="$IG1-$GB1$G$PA"; }
			if (($FLG1A==1) && ($FLG2A==1) && ($FLG3A==1) && ($FLG4A==1))	{ $BS1="$IG1-$GB1$DA$G$PA"; }
		}

		if(/VTight/ig || /VeryTight/ig) 					{ $MI1="VTight"; }		# Gaussian
		elsif(/Tight/ig) 							{ $MI1="Tight"; }		# Gaussian
		elsif(/OPTTOL = 1.000E-06/g) 						{ $MI1="OPTTOL = 1.0E-06"; }	# GAMESS/FIREFLY
		elsif(/OPTTOL = 1.000E-05/g) 						{ $MI1="OPTTOL = 1.0E-05"; }	# GAMESS/FIREFLY
		elsif(/OPTTOL = 1.000E-04/g) 						{ $MI1="OPTTOL = 1.0E-04"; }	# GAMESS/FIREFLY
		#
		# Code to be further developed...
		#
	}
	close(QMLOGFILE1);
}
else { print "\n\nAt least one geometry optimization output is not correct\n"; }

open(QMLOGFILE2,"< $QMLOG2");
foreach(<QMLOGFILE2>){
	if((/Normal termination/ig) || (/TERMINATED NORMALLY/ig))		{ $okqm2=0; }
}
close(QMLOGFILE2);

my $IG2= my $GB2= my $PB= my $P1B= my $P2B= my $DB= my $D1B= my $D2B= my $FLG1B= my $FLG2B= my $FLG3B= my $FLG4B=0;

if ($okqm2==0) {
	open(QMLOGFILE2,"< $QMLOG2");
	foreach(<QMLOGFILE2>){
		if(/M.W.SCHMIDT, K.K.BALDRIDGE, J.A.BOATZ/g) 				{ $QMSOFT2="GAMESS"; }
		elsif(/gran\@classic.chem.msu.su/g) 					{ $QMSOFT2="FIREFLY"; }
		elsif(/Gaussian 98:/g) 							{ $QMSOFT2="GAUSSIAN 1998"; }
		elsif(/Gaussian 03:/g) 							{ $QMSOFT2="GAUSSIAN 2003"; }
		elsif(/Gaussian 09:/g) 							{ $QMSOFT2="GAUSSIAN 2009"; }

		if(/E\(RHF\)/ig || /SCFTYP=RHF/g) 					{ $TL2="RHF"; }			# Gaussian & GAMESS/Firefly
		elsif(/UHF/ig || /SCFTYP=UHF/g) 					{ $TL2="UHF"; }			# Gaussian & GAMESS/Firefly

		if(/6-31G\*/ig || /6-31G\(d\)/ig) 					{ $BS2="6-31G*"; }		# Gaussian
		elsif(/6-311G\*/ig || /6-311G\(d\)/ig) 					{ $BS2="6-311G*"; }
		elsif(/6-31\+G\*/ig || /6-31\+G\(d\)/ig) 				{ $BS2="6-31+G*"; }
		elsif(/6-31\+\+G\*/ig || /6-31\+\+G\(d\)/ig) 				{ $BS2="6-31++G*"; }
		elsif(/6-31\+\+G\*\*/ig || /6-31\+\+G\(d\,p\)/ig) 			{ $BS2="6-31++G**"; }

		else {													# GAMESS/FIREFLY
			#     GBASIS=N31          IGAUSS=       6      POLAR=POPN31  
			#     NDFUNC=       1     NFFUNC=       0     DIFFSP=       F
			#     NPFUNC=       0      DIFFS=       F     BASNAM=        
			if (/GBASIS=N311/g)						{ $GB2="311"; $FLG1B=1; }
			if (/GBASIS=N31/g)						{ $GB2="31";  $FLG1B=1; }
			if (/GBASIS=N21/g)						{ $GB2="21";  $FLG1B=1; }
			if (/GBASIS=STO/g)						{ $GB2="STO"; $FLG1B=1; }

			if (/IGAUSS=       6/g)						{ $IG2="6";   $FLG2B=1; }
			if (/IGAUSS=       3/g)						{ $IG2="3";   $FLG2B=1; }

			if (/NDFUNC=       1/g)						{ $P1B='1'; }
			if (/NPFUNC=       1/g)						{ $P2B='1'; }
			if ($P1B==1)							{ $PB='*';    $FLG3B=1; }
			if (($P1B==1) && ($P2B==1))					{ $PB='**';   $FLG3B=1; }

			if (/DIFFS=       T/g)						{ $D1B='1'; }
			if (/DIFFSP=       T/g)						{ $D2B='1'; }
			if ($D1B==1)							{ $DB='+';    $FLG4B=1; }
			if (($D1B==1) && ($D2B==1))					{ $DB='++';   $FLG4B=1; }

			if (($FLG1B==1) && ($FLG2B==1) && ($FLG3B==1))			{ $BS2="$IG2-$GB2$G$PB"; }
			if (($FLG1B==1) && ($FLG2B==1) && ($FLG3B==1) && ($FLG4B==1))	{ $BS2="$IG2-$GB2$DB$G$PB"; }
		}

		if(/IOp\(6\/33=2\)/ig) 							{ $MI2="IOp(6/33=2)"; }

		if(/Merz-Kollman/ig || /CONNOLLY/ig) 					{ $SA="CONNOLLY SURFACE"; }	# Gaussian & GAMESS/Firefly
		if(/chelpg/ig) 								{ $SA="CHELPG"; }  		# Gaussian & GAMESS/Firefly
		#
		# Code to be further developed...
		#
	}
	close(QMLOGFILE2);
	# print "\n\n$TL2 - $BS2 : $IG2.$GB2.$PB.$DA \n";
}
else { print "\n\nAt least one MEP computation output is not correct\n"; }

print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#=========== INFORMATION REGARDING QUANTUM CHEMISTRY CALCULATIONS =============\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#========================= Geometry optimization ==============================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================ Program =====================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Choose between GAMESS-US, GAUSSIAN 1998, GAUSSIAN 2003, GAUSSIAN 2009,\n";
print CONFIG "# Firefly, Jaguar, NWChem, Q-CHEM or Other\n";
print CONFIG "#\n";
print CONFIG "<Geo_Program>\n";
print CONFIG "$QMSOFT1\n";
print CONFIG "<!_Geo_Program>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============================== Theory Level ==================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Choose between HF\n";
print CONFIG "#                AM1, PM3, etc...\n";
print CONFIG "#                MP2, MP3, MP4(SDQ), MP4(SDTQ)\n";
print CONFIG "#                B3LYP, PBE1PBE, BP86, PW91PW91, PBEPBE, etc...\n";
print CONFIG "#\n";
print CONFIG "<Geo_TL>\n";
print CONFIG "$TL1\n";
print CONFIG "<!_Geo_TL>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================ Basis Set ===================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Examples 6-31G*\n";
print CONFIG "#          6-31G**\n";
print CONFIG "#          6-311++G**, etc...\n";
print CONFIG "#\n";
print CONFIG "<Geo_BasisSet>\n";
print CONFIG "$BS1\n";
print CONFIG "<!_Geo_BasisSet>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============================ More information ================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#\n";
print CONFIG "# More information about keywords used in the geometry optimization (optional):\n";
print CONFIG "#\n";
print CONFIG "<Geo_MoreInfo>\n";
print CONFIG "$MI1\n";
print CONFIG "<!_Geo_MoreInfo>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============== Molecular electrostatic potential computation =================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================ Program =====================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Choose between GAMESS-US, GAUSSIAN 1998, GAUSSIAN 2003, GAUSSIAN 2009,\n";
print CONFIG "# Firefly, Jaguar, NWChem, Q-CHEM or Other\n";
print CONFIG "#\n";
print CONFIG "<Elec_Program>\n";
print CONFIG "$QMSOFT2\n";
print CONFIG "<!_Elec_Program>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================== Theory Level ==============================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Choose between HF\n";
print CONFIG "#                AM1, PM3, etc...\n";
print CONFIG "#                MP2, MP3, MP4(SDQ), MP4(SDTQ)\n";
print CONFIG "#                B3LYP, PBE1PBE, BP86, PW91PW91, PBEPBE, etc...\n";
print CONFIG "#\n";
print CONFIG "<Elec_TL>\n";
print CONFIG "$TL2\n";
print CONFIG "<!_Elec_TL>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================ Basis Set ===================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Examples 6-31G*\n";
print CONFIG "#          6-31G**\n";
print CONFIG "#          6-311++G**, etc...\n";
print CONFIG "#\n";
print CONFIG "<Elec_BasisSet>\n";
print CONFIG "$BS2\n";
print CONFIG "<!_Elec_BasisSet>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============================ More information ================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#\n";
print CONFIG "# More information about keywords used in MEP computation (optional):\n";
print CONFIG "#\n";
print CONFIG "<Elec_MoreInfo>\n";
print CONFIG "$MI2\n";
print CONFIG "<!_Elec_MoreInfo>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============================= Surface algorithm ==============================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";
print CONFIG "# Choose between Connolly surface, CHELPG, CHELP, GEODESIC\n";
print CONFIG "# or Other\n";
print CONFIG "#\n";
print CONFIG "<Elec_SurfAlgo>\n";
print CONFIG "$SA\n";
print CONFIG "<!_Elec_SurfAlgo>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============== INFORMATION REGARDING THE CHARGE FITTING STEP =================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============================== RESP program ==================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# Automatically determined...\n";

$nbinp = 1;
print CONFIG "# Index of the input file\n";
print CONFIG "# (PF) provide the path to the input file and the filename.\n";
print CONFIG "#\n";
print CONFIG "# Index <!>    (PF) \n";
print CONFIG "#\n";
print CONFIG "<Input_file>\n";
if (-e "$ARGV[0]/$dir/input0_m1") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/input0_m1\n"; $nbinp++; }
if (-e "$ARGV[0]/$dir/input1_m1") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/input1_m1\n"; $nbinp++; }
if (-e "$ARGV[0]/$dir/input2_m1") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/input2_m1\n"; $nbinp++; }
if (-e "$ARGV[0]/$dir/input3_m1") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/input3_m1\n"; $nbinp++; }
if (-e "$ARGV[0]/$dir/input4_m1") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/input4_m1\n"; $nbinp++; }

if (-e "$ARGV[0]/$dir/Mol_MM/input0_mm") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/Mol_MM/input0_mm\n"; $nbinp++;; }
if (-e "$ARGV[0]/$dir/Mol_MM/input1_mm") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/Mol_MM/input1_mm\n"; $nbinp++;; }
if (-e "$ARGV[0]/$dir/Mol_MM/input2_mm") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/Mol_MM/input2_mm\n"; $nbinp++;; }
if (-e "$ARGV[0]/$dir/Mol_MM/input3_mm") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/Mol_MM/input3_mm\n"; $nbinp++;; }
if (-e "$ARGV[0]/$dir/Mol_MM/input4_mm") { print CONFIG "File  $nbinp <!> $ARGV[0]/$dir/Mol_MM/input4_mm\n"; $nbinp++;; }

$nbinp--;
if ($nbinp==0) {
	print "\n\nError, no input file found for the RESP program...\n";
	print CONFIG "File  $nbinp <!> __________\n";
}
print CONFIG "<!_Input_file>\n";

print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#======================== FORCE FIELD RELATED FILES ===========================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#\n";
print CONFIG "# Do you wish to upload force field related files compatible with the current\n";
print CONFIG "# project?\n";
print CONFIG "# - File 1: Convertion of Tripos mol2 files into AMBER OFF libraries\n";
print CONFIG "# - File 2: Convertion of Tripos mol2 files into CHARMM RTF or PSF files\n";
print CONFIG "# - File 3: Missing force field parameters\n";
print CONFIG "# - File 4: File to provide more information about the project such a .jpg image\n";
print CONFIG "# - File 5: File to provide more information about the project\n";
print CONFIG "#\n";
print CONFIG "# Index of the file\n";
print CONFIG "# (YN) 'Yes' or 'No'; default value = 'No'.\n";
print CONFIG "# (PF) If Yes, provide the path to the file and the filename.\n";
print CONFIG "#                      the path to the file = $ARGV[0]/\n";
print CONFIG "#\n";
print CONFIG "# Index <!> YN  <!>    (PF) \n";
print CONFIG "#\n";
print CONFIG "<FF_File>\n";
$nbscript = 1;
if (-e "$ARGV[0]/script1.ff") { print CONFIG "File  1 <!> Yes <!> $ARGV[0]/script1.ff\n"; $nbscript++; }
else { print CONFIG "File  1 <!> No  <!> __________\n"; }
if (-e "$ARGV[0]/script2.ff") { print CONFIG "File  2 <!> Yes <!> $ARGV[0]/script2.ff\n"; $nbscript++; }
else { print CONFIG "File  2 <!> No  <!> __________\n"; }
if (-e "$ARGV[0]/script3.ff") { print CONFIG "File  3 <!> Yes <!> $ARGV[0]/script3.ff\n"; $nbscript++; }
else { print CONFIG "File  3 <!> No  <!> __________\n"; }
if (-e "$ARGV[0]/script4.ff") { print CONFIG "File  4 <!> Yes <!> $ARGV[0]/script4.ff\n"; $nbscript++; }
else { print CONFIG "File  4 <!> No  <!> __________\n"; }
if (-e "$ARGV[0]/script5.ff") { print CONFIG "File  5 <!> Yes <!> $ARGV[0]/script5.ff\n"; $nbscript++; }
else { print CONFIG "File  5 <!> No  <!> __________\n"; }
print CONFIG "<!_FF_File>\n";
$nbscript--;

if ($nbscript==0) { 
	print "\n\nWarning, no force field related file found in the directory \"$ARGV[0]\"!\n\n";
	print "If you do want to provide one or several of these files (script1.ff - script5.ff) in your R.E.DD.B. project\nsimply, copy the corresponding file(s) in \"$ARGV[0]\", and re-run this script...\n";
}

print "\n\nnbp2n=$nbp2ntot; nbmol2=$nbmol2; nbinp=$nbinp; nbscript=$nbscript\n";

print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#============== Information about the number of P2N files =====================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "# \n";
print CONFIG "# WARNING: DO NOT MODIFY THIS VALUE!\n";
print CONFIG "<nbp2n>\n";
print CONFIG "$nbp2ntot\n";
print CONFIG "<!_nbp2n>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#==================== Information about the pathfile ==========================\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#\n";
print CONFIG "# WARNING: DO NOT MODIFY THIS VALUE!\n";
print CONFIG "<Pathfile>\n";
print CONFIG "$ARGV[0]/$dir\n";
print CONFIG "<!_Pathfile>\n";
print CONFIG "#\n";
print CONFIG "#==============================================================================\n";
print CONFIG "#================================ Finished ====================================\n";
print CONFIG "#==============================================================================";
close(CONFIG);
print "\n";
print "==================================================================\n";
print "$ARGV[0]-config.cfg created\t\t\t\t[OK]\n\n";
print "Please, edit/complete the \"$ARGV[0]-config.cfg\" file, and then \n";
print "        execute \"perl Script2-REDDB.pl $ARGV[0]-config.cfg\".\n";
print "==================================================================\n";
print "\n";
}
